pub enum ReliableClientFrame {
Data {
sequence: u64,
payload: Vec<u8>,
},
Ack {
sequence: u64,
},
}Expand description
Encoded reliable client frame.
Variants
Implementations
Sourceimpl ReliableClientFrame
impl ReliableClientFrame
Sourcepub fn encode_data(
sequence: u64,
payload: &[u8],
out: &mut Vec<u8>,
) -> Result<(), ReliableClientEncodeError>
pub fn encode_data( sequence: u64, payload: &[u8], out: &mut Vec<u8>, ) -> Result<(), ReliableClientEncodeError>
Appends a data frame from a borrowed payload without materializing an owned frame.
Sourcepub fn encode(&self, out: &mut Vec<u8>) -> Result<(), ReliableClientEncodeError>
pub fn encode(&self, out: &mut Vec<u8>) -> Result<(), ReliableClientEncodeError>
Encodes a reliable client frame.
Sourcepub fn decode(input: &[u8]) -> Result<Self, ReliableClientDecodeError>
pub fn decode(input: &[u8]) -> Result<Self, ReliableClientDecodeError>
Decodes a reliable client frame.
Sourcepub fn decode_ref(
input: &[u8],
) -> Result<ReliableClientFrameRef<'_>, ReliableClientDecodeError>
pub fn decode_ref( input: &[u8], ) -> Result<ReliableClientFrameRef<'_>, ReliableClientDecodeError>
Decodes a reliable client frame while borrowing data payload bytes.