ReliableStationFrame

Enum ReliableStationFrame 

pub enum ReliableStationFrame {
    Data {
        sequence: u64,
        payload: Vec<u8>,
    },
    Ack {
        sequence: u64,
    },
}
Encoded reliable station frame.

Variants



Data

Reliable data packet.

Fields

sequence: u64

Sender-local sequence number scoped to the target station.

payload: Vec<u8>

Original station packet payload.



Ack

Acknowledgement for a reliable data packet.

Fields

sequence: u64

Acknowledged sequence number.

Implementations

Source

impl ReliableStationFrame

pub fn encode_data( sequence: u64, payload: &[u8], out: &mut Vec<u8>, ) -> Result<(), ReliableStationEncodeError>

Appends a data frame from a borrowed payload without materializing an owned frame.

pub fn encode( &self, out: &mut Vec<u8>, ) -> Result<(), ReliableStationEncodeError>

Encodes a reliable station frame.

pub fn decode(input: &[u8]) -> Result<Self, ReliableStationDecodeError>

Decodes a reliable station frame.

pub fn decode_ref( input: &[u8], ) -> Result<ReliableStationFrameRef<'_>, ReliableStationDecodeError>

Decodes a reliable Station frame while borrowing data payload bytes.