pub struct InMemoryStationTransportStats {
pub packets_sent: usize,
pub packets_received: usize,
pub bytes_sent: usize,
pub bytes_received: usize,
pub packets_rejected_full: usize,
pub packets_rejected_bytes: usize,
}Expand description
Statistics for the bounded in-memory station transport.
Fields
packets_sent: usizePackets accepted for delivery.
packets_received: usizePackets received by target stations.
bytes_sent: usizeBytes accepted for delivery.
bytes_received: usizeBytes received by target stations.
packets_rejected_full: usizePackets rejected because the target station queue was full.
packets_rejected_bytes: usizePackets rejected because they exceeded the packet byte budget.