InMemoryTransportHub

Struct InMemoryTransportHub 

pub struct InMemoryTransportHub { /* private fields */ }
Shared bounded in-memory client packet hub.

Implementations

Source

impl InMemoryTransportHub

pub fn new(limits: ClientTransportLimits) -> Self

Creates an empty in-memory transport hub.

pub fn register_client( &self, client_id: ClientId, remote_addr: SocketAddr, ) -> Result<Option<SocketAddr>, InMemoryTransportError>

Registers a client endpoint address.

pub fn endpoint( &self, client_id: ClientId, remote_addr: SocketAddr, ) -> Result<InMemoryTransportEndpoint, InMemoryTransportError>

Registers and returns a local endpoint for a client.

pub fn endpoint_for_registered( &self, client_id: ClientId, ) -> InMemoryTransportEndpoint

Returns an endpoint handle for a client that should already be registered.

pub fn unregister_client( &self, client_id: ClientId, ) -> Result<Option<InMemoryClientUnregister>, InMemoryTransportError>

Unregisters a client and releases its queued packet storage.

pub fn queued_len( &self, client_id: ClientId, ) -> Result<Option<usize>, InMemoryTransportError>

Returns queued packet count for a client.

pub fn queued_capacity( &self, client_id: ClientId, ) -> Result<Option<usize>, InMemoryTransportError>

Returns packet slots retained by one client queue.

pub fn retained_queue_capacity(&self) -> Result<usize, InMemoryTransportError>

Returns packet slots retained across all registered client queues.

pub fn limits(&self) -> Result<ClientTransportLimits, InMemoryTransportError>

Returns configured limits.

pub fn stats(&self) -> Result<InMemoryTransportStats, InMemoryTransportError>

Returns transport statistics.