pub struct PacketSecurityEnvelope {
pub key_id: u32,
pub nonce: u64,
pub payload: Vec<u8>,
pub tag: Vec<u8>,
}Expand description
Owned packet security envelope.
Fields
key_id: u32External key identifier chosen by the embedder.
nonce: u64Nonce scoped to key_id.
payload: Vec<u8>Ciphertext or plaintext payload, depending on the configured cipher.
tag: Vec<u8>Authentication tag produced by the configured authenticator.
Implementations
Sourceimpl PacketSecurityEnvelope
impl PacketSecurityEnvelope
Sourcepub fn encode_parts(
config: PacketSecurityConfig,
key_id: u32,
nonce: u64,
payload: &[u8],
tag: &[u8],
out: &mut Vec<u8>,
) -> Result<(), PacketSecurityEncodeError>
pub fn encode_parts( config: PacketSecurityConfig, key_id: u32, nonce: u64, payload: &[u8], tag: &[u8], out: &mut Vec<u8>, ) -> Result<(), PacketSecurityEncodeError>
Appends an envelope from borrowed payload and tag slices.
Sourcepub fn encode(
&self,
config: PacketSecurityConfig,
out: &mut Vec<u8>,
) -> Result<(), PacketSecurityEncodeError>
pub fn encode( &self, config: PacketSecurityConfig, out: &mut Vec<u8>, ) -> Result<(), PacketSecurityEncodeError>
Encodes a packet security envelope.
Sourcepub fn decode(
config: PacketSecurityConfig,
input: &[u8],
) -> Result<Self, PacketSecurityDecodeError>
pub fn decode( config: PacketSecurityConfig, input: &[u8], ) -> Result<Self, PacketSecurityDecodeError>
Decodes a packet security envelope.