pub struct PacketSecurityEnvelopeRef<'a> {
pub key_id: u32,
pub nonce: u64,
pub payload: &'a [u8],
pub tag: &'a [u8],
}Expand description
Borrowed packet security envelope decoded directly from wire bytes.
Fields
key_id: u32External key identifier chosen by the embedder.
nonce: u64Nonce scoped to key_id.
payload: &'a [u8]Borrowed ciphertext or plaintext payload.
tag: &'a [u8]Borrowed authentication tag.
Implementations
Sourceimpl<'a> PacketSecurityEnvelopeRef<'a>
impl<'a> PacketSecurityEnvelopeRef<'a>
Sourcepub fn decode(
config: PacketSecurityConfig,
input: &'a [u8],
) -> Result<Self, PacketSecurityDecodeError>
pub fn decode( config: PacketSecurityConfig, input: &'a [u8], ) -> Result<Self, PacketSecurityDecodeError>
Decodes and validates an envelope without copying payload or tag bytes.