pub struct PacketSecurityScratch { /* private fields */ }Expand description
Caller-owned reusable payload and tag storage for packet sealing.
Implementations
Sourceimpl PacketSecurityScratch
impl PacketSecurityScratch
Sourcepub fn with_capacity(payload_bytes: usize, tag_bytes: usize) -> Self
pub fn with_capacity(payload_bytes: usize, tag_bytes: usize) -> Self
Creates sealing storage with explicit payload and tag capacities.
Sourcepub fn retained_payload_capacity(&self) -> usize
pub fn retained_payload_capacity(&self) -> usize
Encrypted-payload bytes retained without growing the scratch buffer.
Sourcepub fn retained_tag_capacity(&self) -> usize
pub fn retained_tag_capacity(&self) -> usize
Authentication-tag bytes retained without growing the scratch buffer.