pub enum ReliableStationFrame {
Data {
sequence: u64,
payload: Vec<u8>,
},
Ack {
sequence: u64,
},
}Expand description
Encoded reliable station frame.
Variants
Implementations
Sourceimpl ReliableStationFrame
impl ReliableStationFrame
Sourcepub fn encode_data(
sequence: u64,
payload: &[u8],
out: &mut Vec<u8>,
) -> Result<(), ReliableStationEncodeError>
pub fn encode_data( sequence: u64, payload: &[u8], out: &mut Vec<u8>, ) -> Result<(), ReliableStationEncodeError>
Appends a data frame from a borrowed payload without materializing an owned frame.
Sourcepub fn encode(
&self,
out: &mut Vec<u8>,
) -> Result<(), ReliableStationEncodeError>
pub fn encode( &self, out: &mut Vec<u8>, ) -> Result<(), ReliableStationEncodeError>
Encodes a reliable station frame.
Sourcepub fn decode(input: &[u8]) -> Result<Self, ReliableStationDecodeError>
pub fn decode(input: &[u8]) -> Result<Self, ReliableStationDecodeError>
Decodes a reliable station frame.
Sourcepub fn decode_ref(
input: &[u8],
) -> Result<ReliableStationFrameRef<'_>, ReliableStationDecodeError>
pub fn decode_ref( input: &[u8], ) -> Result<ReliableStationFrameRef<'_>, ReliableStationDecodeError>
Decodes a reliable Station frame while borrowing data payload bytes.